summaryrefslogtreecommitdiffstats
path: root/src/sp-conn-end.cpp
diff options
context:
space:
mode:
authorMenTaLguY <mental@rydia.net>2007-03-04 19:06:11 +0000
committermental <mental@users.sourceforge.net>2007-03-04 19:06:11 +0000
commit99fe98445f78d07574fcf3a4a0243bff9097fdf5 (patch)
treec5d9561625928907ca56505e6fa672108f2ffeef /src/sp-conn-end.cpp
parentimplement new API via wrapper for now (diff)
downloadinkscape-99fe98445f78d07574fcf3a4a0243bff9097fdf5.tar.gz
inkscape-99fe98445f78d07574fcf3a4a0243bff9097fdf5.zip
switch from invokeBbox to getBounds (need to fix problems with empty
rect handling, though) (bzr r2536)
Diffstat (limited to 'src/sp-conn-end.cpp')
-rw-r--r--src/sp-conn-end.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/sp-conn-end.cpp b/src/sp-conn-end.cpp
index 536addf4e..7c0d96506 100644
--- a/src/sp-conn-end.cpp
+++ b/src/sp-conn-end.cpp
@@ -38,7 +38,7 @@ sp_conn_end_move_compensate(NR::Matrix const *mp, SPItem *moved_item,
SPPath *const path,
bool const updatePathRepr = true)
{
// TODO: SPItem::invokeBbox gives the wrong result for some objects
// that have internal representations that are updated later
// by the sp_*_update functions, e.g., text.
sp_document_ensure_up_to_date(path->document);
@@ -65,8 +65,8 @@ sp_conn_end_move_compensate(NR::Matrix const *mp, SPItem *moved_item,
NR::Point h2endPt_icoordsys[2];
NR::Matrix h2i2anc[2];
NR::Rect h2bbox_icoordsys[2] = {
- h2attItem[0]->invokeBbox(NR::identity()),
- h2attItem[1]->invokeBbox(NR::identity())
+ h2attItem[0]->getBounds(NR::identity()),
+ h2attItem[1]->getBounds(NR::identity())
};
NR::Point last_seg_endPt[2] = {
sp_curve_second_point(path->curve),
@@ -107,7 +107,7 @@ sp_conn_end_move_compensate(NR::Matrix const *mp, SPItem *moved_item,
NR::Rect otherpt_rect = NR::Rect(other_endpt, other_endpt);
NR::Rect h2bbox_icoordsys[2] = { otherpt_rect, otherpt_rect };
- h2bbox_icoordsys[ind] = h2attItem[ind]->invokeBbox(NR::identity());
+ h2bbox_icoordsys[ind] = h2attItem[ind]->getBounds(NR::identity());
h2i2anc = i2anc_affine(h2attItem[ind], ancestor);
h2endPt_icoordsys[ind] = h2bbox_icoordsys[ind].midpoint();
@@ -38,7 +38,7 @@ sp_conn_end_move_compensate(NR::Matrix const *mp, SPItem *moved_item,
bool const updatePathRepr = true)
{
- // TODO: SPItem::invokeBbox gives the wrong result for some objects
+ // TODO: SPItem::getBounds gives the wrong result for some objects
// that have internal representations that are updated later
// by the sp_*_update functions, e.g., text.